/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.object.exception;

import com.liferay.portal.kernel.exception.PortalException;

/**
 * @author Marco Leo
 */
public class ObjectDefinitionNameException extends PortalException {

	public ObjectDefinitionNameException() {
	}

	public ObjectDefinitionNameException(String msg) {
		super(msg);
	}

	public ObjectDefinitionNameException(String msg, Throwable throwable) {
		super(msg, throwable);
	}

	public ObjectDefinitionNameException(Throwable throwable) {
		super(throwable);
	}

	public static class MustBeginWithUpperCaseLetter
		extends ObjectDefinitionNameException {

		public MustBeginWithUpperCaseLetter() {
			super("The first character of a name must be an upper case letter");
		}

	}

	public static class MustBeLessThan41Characters
		extends ObjectDefinitionNameException {

		public MustBeLessThan41Characters() {
			super("Names must be less than 41 characters");
		}

	}

	public static class MustNotBeDuplicate
		extends ObjectDefinitionNameException {

		public MustNotBeDuplicate(String name) {
			super("Duplicate name " + name);
		}

	}

	public static class MustNotBeNull extends ObjectDefinitionNameException {

		public MustNotBeNull() {
			super("Name is null");
		}

	}

	public static class MustNotStartWithCAndUnderscoreForSystemObject
		extends ObjectDefinitionNameException {

		public MustNotStartWithCAndUnderscoreForSystemObject() {
			super("System object definition names must not start with \"C_\"");
		}

	}

	public static class MustOnlyContainLettersAndDigits
		extends ObjectDefinitionNameException {

		public MustOnlyContainLettersAndDigits() {
			super("Name must only contain letters and digits");
		}

	}

	public static class MustStartWithCAndUnderscoreForCustomObject
		extends ObjectDefinitionNameException {

		public MustStartWithCAndUnderscoreForCustomObject() {
			super("Custom object definition names must start with \"C_\"");
		}

	}

}